/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import { Construct } from 'constructs';
import * as s3 from 'aws-cdk-lib/aws-s3';
import * as sfn from 'aws-cdk-lib/aws-stepfunctions';
import * as logs from 'aws-cdk-lib/aws-logs';
export interface S3BucketFactoryProps {
    readonly bucketProps?: s3.BucketProps | any;
    readonly logS3AccessLogs?: boolean;
    readonly loggingBucketProps?: s3.BucketProps;
}
export interface S3BucketFactoryResponse {
    readonly s3Bucket: s3.Bucket;
    readonly s3LoggingBucket?: s3.Bucket;
}
export interface StateMachineFactoryProps {
    /**
     * The CDK properties that define the state machine. This property is required and
     * must include a definitionBody or definition (definition is deprecated)
     */
    readonly stateMachineProps: sfn.StateMachineProps;
    /**
     * An existing LogGroup to which the new state machine will write log entries.
     *
     * Default: none, the construct will create a new log group.
     */
    readonly logGroupProps?: logs.LogGroupProps;
}
export interface StateMachineFactoryResponse {
    /**
     * The state machine created by the factory (the state machine role is
     * available as a property on this resource)
     */
    readonly stateMachine: sfn.StateMachine;
    /**
     * The log group that will receive log messages from the state maching
     */
    readonly logGroup: logs.ILogGroup;
}
export declare class ConstructsFactories extends Construct {
    constructor(scope: Construct, id: string);
    s3BucketFactory(id: string, props: S3BucketFactoryProps): S3BucketFactoryResponse;
    stateMachineFactory(id: string, props: StateMachineFactoryProps): StateMachineFactoryResponse;
}
